==> klayout-0.19.3.tar.gz: klayout-0.19.3/src/gsiCallbackVar.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2007 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


//  This header by intention does not have a include guard
//  It is used multiple times inside gsiCallback.h
//
//  It needs these macros to be defined (example for the one argument case)
//   _TMPLARGPART  ", class A1, class _A1"
//   _FUNCARGLIST  "A1"
//   _CALLARGLIST  ", _A1 a1"
//   _SETVALUE     "args.template set_value (typename type_traits<A1>::tag (), a1);"

template <class X _TMPLARGPART>
void issue (const Callback &cb, void (X::*f) (_FUNCARGLIST) _CALLARGLIST) 
{
  SerialArgs args (cb.argsize), ret (cb.retsize);
  _SETVALUE
  cb.call (args, ret);
}

template <class X _TMPLARGPART>
void issue (const Callback &cb, void (X::*f) (_FUNCARGLIST) const _CALLARGLIST) 
{
  SerialArgs args (cb.argsize), ret (cb.retsize);
  _SETVALUE
  cb.call (args, ret);
}

template <class X, class R _TMPLARGPART>
R issue (const Callback &cb, R (X::*f) (_FUNCARGLIST) _CALLARGLIST) 
{
  SerialArgs args (cb.argsize), ret (cb.retsize);
  _SETVALUE
  cb.call (args, ret);
  return ret.template get_value<R> (typename type_traits<R>::tag ());
}

template <class X, class R _TMPLARGPART>
R issue (const Callback &cb, R (X::*f) (_FUNCARGLIST) const _CALLARGLIST)
{
  SerialArgs args (cb.argsize), ret (cb.retsize);
  _SETVALUE
  cb.call (args, ret);
  return ret.template get_value<R> (typename type_traits<R>::tag ());
}

==> klayout-0.23.10.tar.gz: klayout-0.23.10/src/gsiCallbackVar.h <==

/*

  KLayout Layout Viewer
  Copyright (C) 2006-2015 Matthias Koefferlein

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/


//  This header by intention does not have a include guard
//  It is used multiple times inside gsiCallback.h
//
//  It needs these macros to be defined (example for the one argument case)
//   _TMPLARGPART  ", class A1"
//   _FUNCARGLIST  "A1"
//   _CALLARGLIST  ", A1 a1"
//   _SETVALUE     "args.template set_value (typename type_traits<A1>::tag (), a1);"

template <class X _TMPLARGPART>
void issue (const Callback &cb, void (X::*f) (_FUNCARGLIST) _CALLARGLIST) 
{
  SerialArgs args (cb.argsize), ret (cb.retsize);
  _SETVALUE
  cb.call (args, ret);
}

template <class X _TMPLARGPART>
void issue (const Callback &cb, void (X::*f) (_FUNCARGLIST) const _CALLARGLIST) 
{
  SerialArgs args (cb.argsize), ret (cb.retsize);
  _SETVALUE
  cb.call (args, ret);
}

template <class X, class R _TMPLARGPART>
R issue (const Callback &cb, R (X::*f) (_FUNCARGLIST) _CALLARGLIST) 
{
  SerialArgs args (cb.argsize), ret (cb.retsize);
  _SETVALUE
  cb.call (args, ret);
  return ret.template get_value<R> (typename type_traits<R>::tag ());
}

template <class X, class R _TMPLARGPART>
R issue (const Callback &cb, R (X::*f) (_FUNCARGLIST) const _CALLARGLIST)
{
  SerialArgs args (cb.argsize), ret (cb.retsize);
  _SETVALUE
  cb.call (args, ret);
  return ret.template get_value<R> (typename type_traits<R>::tag ());
}
